###################################################
### chunk number 1: preliminaries
###################################################
library("marelac")
options(prompt = "> ")
options(width=75)


###################################################
### chunk number 2: 
###################################################
data.frame(cbind(acronym=names(Constants),
             matrix(ncol=3,byrow=TRUE,data=unlist(Constants),
             dimnames=list(NULL,c("value","units","description")))))



###################################################
### chunk number 3: 
###################################################
data.frame(cbind(acronym=names(Oceans),
             matrix(ncol=3,byrow=TRUE,data=unlist(Oceans),
             dimnames=list(NULL,c("value","units","description")))))


###################################################
### chunk number 4: bat
###################################################
require(marelac)
image(Bathymetry$x,Bathymetry$y,Bathymetry$z,col=femmecol(100),
      asp=TRUE,xlab="",ylab="")
contour(Bathymetry$x,Bathymetry$y,Bathymetry$z,add=TRUE)


###################################################
### chunk number 5: batfig
###################################################
require(marelac)
image(Bathymetry$x,Bathymetry$y,Bathymetry$z,col=femmecol(100),
      asp=TRUE,xlab="",ylab="")
contour(Bathymetry$x,Bathymetry$y,Bathymetry$z,add=TRUE)


###################################################
### chunk number 6: 
###################################################
SURF <- outer(X=Bathymetry$x,
               Y=Bathymetry$y,
               FUN <- function(X,Y) earth_surf(Y,X))
sum(SURF)


###################################################
### chunk number 7: 
###################################################
 sum(SURF*(Bathymetry$z<0))

- sum(SURF*Bathymetry$z*(Bathymetry$z<0))


###################################################
### chunk number 8: 
###################################################
SurfDepth <- vector()

dseq <- seq(-7500,-250,by=250)

for (i in 2:length(dseq)) {
  ii <- which (Bathymetry$z>dseq[i-1]&Bathymetry$z<=dseq[i])
  SurfDepth[i-1]<-sum(SURF[ii])
}


###################################################
### chunk number 9: ocean
###################################################
plot(dseq[-1],SurfDepth, xlab="depth, m", log="y",
     ylab = "m2", main = "Surface at ocean depths")


###################################################
### chunk number 10: ocean
###################################################
plot(dseq[-1],SurfDepth, xlab="depth, m", log="y",
     ylab = "m2", main = "Surface at ocean depths")


###################################################
### chunk number 11: 
###################################################
AtomicWeight
AtomicWeight[8,]
(W_H2O<- with (atomicweight, 2 * H + O))


###################################################
### chunk number 12: 
###################################################
atmComp("O2")
atmComp()
sum(atmComp())    #!


###################################################
### chunk number 13: cor
###################################################
plot(-90:90,coriolis(-90:90),xlab="latitude, dg North",
                 ylab= "/s" , main ="Coriolis factor",type="l",lwd=2)


###################################################
### chunk number 14: figcor
###################################################
plot(-90:90,coriolis(-90:90),xlab="latitude, dg North",
                 ylab= "/s" , main ="Coriolis factor",type="l",lwd=2)


###################################################
### chunk number 15: 
###################################################
diffcoeff(S=15,t=15)*24*3600*1e4  # cm2/day
diffcoeff(t=10)$O2


###################################################
### chunk number 16: 
###################################################
difftemp <- diffcoeff(t=0:30)[,1:13]


###################################################
### chunk number 17: diff
###################################################
matplot(0:30,difftemp,xlab="temperature",ylab=" m2/sec",
        main="Molecular/ionic diffusion",type="l")
legend("topleft",ncol=2,cex=0.8,title="mean",col=1:13,lty=1:13,
        legend=cbind(names(difftemp),format(colMeans(difftemp),digits=4)))


###################################################
### chunk number 18: figdif
###################################################
matplot(0:30,difftemp,xlab="temperature",ylab=" m2/sec",
        main="Molecular/ionic diffusion",type="l")
legend("topleft",ncol=2,cex=0.8,title="mean",col=1:13,lty=1:13,
        legend=cbind(names(difftemp),format(colMeans(difftemp),digits=4)))


###################################################
### chunk number 19: visc
###################################################
plot(0:30,viscosity(S=35,t=0:30,P=1),xlab="temperature",ylab="g/m/s",
       main="shear viscosity of water",type="l")
lines(0:30,viscosity(S=0,t=0:30,P=1),col="red")
lines(0:30,viscosity(S=35,t=0:30,P=100),col="blue")
legend("topright",col=c("black","red","blue"),lty=1,
        legend=c("S=35,P=1","S=0,P=1","S=35,P=100"))


###################################################
### chunk number 20: figshear
###################################################
plot(0:30,viscosity(S=35,t=0:30,P=1),xlab="temperature",ylab="g/m/s",
       main="shear viscosity of water",type="l")
lines(0:30,viscosity(S=0,t=0:30,P=1),col="red")
lines(0:30,viscosity(S=35,t=0:30,P=100),col="blue")
legend("topright",col=c("black","red","blue"),lty=1,
        legend=c("S=35,P=1","S=0,P=1","S=35,P=100"))


###################################################
### chunk number 21: 
###################################################
gas_O2sat(t = 20)
t <- seq(0, 30, 0.1)


###################################################
### chunk number 22: 
###################################################
gas_O2sat(S=35, t=20)*1000/molweight("O2")


###################################################
### chunk number 23: o2sat
###################################################
  plot(t, gas_O2sat(t = t), type = "l", ylim = c(0, 15), lwd=2,
       main="Oxygen saturation", ylab = "mg/l", xlab="temperature")
  lines(t, gas_O2sat(S = 0, t = t, method = "Weiss"), col = "green",
        lwd = 2, lty = "dashed")
  lines(t, gas_O2sat(S = 35, t = t, method = "Weiss"), col = "red", lwd = 2)
  legend("topright",c("S=35","S=0"),col=c("red","green"), lty=c(1,2), lwd=2)


###################################################
### chunk number 24: figo2sat
###################################################
  plot(t, gas_O2sat(t = t), type = "l", ylim = c(0, 15), lwd=2,
       main="Oxygen saturation", ylab = "mg/l", xlab="temperature")
  lines(t, gas_O2sat(S = 0, t = t, method = "Weiss"), col = "green",
        lwd = 2, lty = "dashed")
  lines(t, gas_O2sat(S = 35, t = t, method = "Weiss"), col = "red", lwd = 2)
  legend("topright",c("S=35","S=0"),col=c("red","green"), lty=c(1,2), lwd=2)


###################################################
### chunk number 25: 
###################################################
gas_satconc(species="O2")
Temp<-seq(from=0,to=30,by=0.1)
Sal <- seq(from=0,to=35,by=0.1)


###################################################
### chunk number 26: solub
###################################################
#
mf  <-par(mfrow=c(2,2))
#
gs  <-gas_solubility(t=Temp)
species   <- c("CCl4","CO2","N2O","Rn","CCl2F2")
matplot(Temp,gs[,species],type="l",lty=1,lwd=2,xlab="temperature",
     ylab="mmol/m3",main="solubility (S=35)")
legend("topright",col=1:5,lwd=2,legend=species)
#
species2 <- c("Kr","CH4","Ar","O2","N2","Ne")
matplot(Temp,gs[,species2],type="l",lty=1,lwd=2,xlab="temperature",
     ylab="mmol/m3",main="solubility (S=35)")
legend("topright",col=1:6,lwd=2,legend=species2)
#

species <- c("N2","CO2","O2","CH4","N2O")
gsat  <-gas_satconc(t=Temp,species=species)
matplot(Temp,gsat,type="l",xlab="temperature",log="y", lty=1,
     ylab="mmol/m3",main="Saturated conc (S=35)",lwd=2)
legend("right",col=1:5,lwd=2,legend=species)
#
gsat  <-gas_satconc(S=Sal,species=species)
matplot(Sal,gsat,type="l",xlab="salinity",log="y", lty=1,
     ylab="mmol/m3",main="Saturated conc (T=20)",lwd=2)
legend("right",col=1:5,lwd=2,legend=species)
#
par("mfrow"=mf)


###################################################
### chunk number 27: figsolub
###################################################
#
mf  <-par(mfrow=c(2,2))
#
gs  <-gas_solubility(t=Temp)
species   <- c("CCl4","CO2","N2O","Rn","CCl2F2")
matplot(Temp,gs[,species],type="l",lty=1,lwd=2,xlab="temperature",
     ylab="mmol/m3",main="solubility (S=35)")
legend("topright",col=1:5,lwd=2,legend=species)
#
species2 <- c("Kr","CH4","Ar","O2","N2","Ne")
matplot(Temp,gs[,species2],type="l",lty=1,lwd=2,xlab="temperature",
     ylab="mmol/m3",main="solubility (S=35)")
legend("topright",col=1:6,lwd=2,legend=species2)
#

species <- c("N2","CO2","O2","CH4","N2O")
gsat  <-gas_satconc(t=Temp,species=species)
matplot(Temp,gsat,type="l",xlab="temperature",log="y", lty=1,
     ylab="mmol/m3",main="Saturated conc (S=35)",lwd=2)
legend("right",col=1:5,lwd=2,legend=species)
#
gsat  <-gas_satconc(S=Sal,species=species)
matplot(Sal,gsat,type="l",xlab="salinity",log="y", lty=1,
     ylab="mmol/m3",main="Saturated conc (T=20)",lwd=2)
legend("right",col=1:5,lwd=2,legend=species)
#
par("mfrow"=mf)


###################################################
### chunk number 28: vapor
###################################################
plot(0:30, vapor(t = 0:30), xlab = "Temperature, dgC", ylab = "pH2O/P",
     type ="l")


###################################################
### chunk number 29: figvapor
###################################################
plot(0:30, vapor(t = 0:30), xlab = "Temperature, dgC", ylab = "pH2O/P",
     type ="l")


###################################################
### chunk number 30: 
###################################################
gas_schmidt(species="CO2",t=20)

useq <- 0:15


###################################################
### chunk number 31: transfer
###################################################
plot(useq,gas_transfer(u10=useq,species="O2"),type="l",lwd=2,xlab="u10,m/s",
     ylab="m/s", main="O2 gas transfer velocity",ylim=c(0,3e-4))
lines(useq,gas_transfer(u10=useq,species="O2",method="Nightingale"),lwd=2,lty=2)
lines(useq,gas_transfer(u10=useq,species="O2",method="Wanninkhof1"),lwd=2,lty=3)
lines(useq,gas_transfer(u10=useq,species="O2",method="Wanninkhof2"),lwd=2,lty=4)

legend("topleft",lty=1:4,lwd=2,legend=c("Liss and Merlivat 1986",
"Nightingale et al. 2000","Wanninkhof 1992","Wanninkhof and McGills 1999"))


###################################################
### chunk number 32: figtransfer
###################################################
plot(useq,gas_transfer(u10=useq,species="O2"),type="l",lwd=2,xlab="u10,m/s",
     ylab="m/s", main="O2 gas transfer velocity",ylim=c(0,3e-4))
lines(useq,gas_transfer(u10=useq,species="O2",method="Nightingale"),lwd=2,lty=2)
lines(useq,gas_transfer(u10=useq,species="O2",method="Wanninkhof1"),lwd=2,lty=3)
lines(useq,gas_transfer(u10=useq,species="O2",method="Wanninkhof2"),lwd=2,lty=4)

legend("topleft",lty=1:4,lwd=2,legend=c("Liss and Merlivat 1986",
"Nightingale et al. 2000","Wanninkhof 1992","Wanninkhof and McGills 1999"))


###################################################
### chunk number 33: 
###################################################
sw_conserv(S=seq(0,35,by=5))


###################################################
### chunk number 34: 
###################################################
convert_AStoPS(S=35)
convert_PStoAS(S=35)


###################################################
### chunk number 35: 
###################################################
convert_PStoAS(S=35,lat=-10,lon=0)
convert_PStoAS(S=35,lat=0,lon=0)
convert_PStoAS(S=35,lat=10,lon=0)
convert_PStoAS(S=35,lat=-10,lon=0)

convert_PStoAS(S=35,lat=-10, DSi=1:10, Ocean="Pacific")

dsal <- t(sw_sfac$del_sa[1,,])
dsal [dsal < -90]<-NA


###################################################
### chunk number 36: sfac
###################################################
image(sw_sfac$longs, sw_sfac$lats, dsal, col=femmecol(100),
      asp=TRUE, xlab="dg", ylab="dg",
      main="salinity conversion - p = 0 bar")
contour(sw_sfac$longs, sw_sfac$lats, dsal, asp=TRUE, add=TRUE)


###################################################
### chunk number 37: sfac
###################################################
image(sw_sfac$longs, sw_sfac$lats, dsal, col=femmecol(100),
      asp=TRUE, xlab="dg", ylab="dg",
      main="salinity conversion - p = 0 bar")
contour(sw_sfac$longs, sw_sfac$lats, dsal, asp=TRUE, add=TRUE)


###################################################
### chunk number 38: sfac2
###################################################
ii <- c(6,21,24,43)
par(mfrow=c(2,2))
for ( i in ii)
{
dsal <- t(sw_sfac$del_sa[,i,])
dsal [dsal < -90]<-0
image(sw_sfac$longs, sw_sfac$p, dsal, col=c("black",femmecol(100)),
      xlab="longitude, dg", ylab="depth, m", zlim=c(0,0.018),
      main=sw_sfac$lat[i],ylim=c(6000,0))
contour(sw_sfac$longs, sw_sfac$p, dsal, asp=TRUE, add=TRUE)
}


###################################################
### chunk number 39: sfac2
###################################################
ii <- c(6,21,24,43)
par(mfrow=c(2,2))
for ( i in ii)
{
dsal <- t(sw_sfac$del_sa[,i,])
dsal [dsal < -90]<-0
image(sw_sfac$longs, sw_sfac$p, dsal, col=c("black",femmecol(100)),
      xlab="longitude, dg", ylab="depth, m", zlim=c(0,0.018),
      main=sw_sfac$lat[i],ylim=c(6000,0))
contour(sw_sfac$longs, sw_sfac$p, dsal, asp=TRUE, add=TRUE)
}


###################################################
### chunk number 40: 
###################################################
sw_cp(S=40,t=1:20)
sw_cp(S=40,t=1:20,method="UNESCO")


###################################################
### chunk number 41: 
###################################################
t  <-  25.5
p  <- 1023/10  # pressure in bar
S  <- 35.7
sw_alpha(S,t,p)               -0.0003098378393192645
sw_beta(S,t,p)                -0.0007257297978386655
sw_cp(S,t,p)                  -3974.42541259729
sw_tpot(S,t,p)                -25.2720983155409
sw_dens(S,t,p)                -1027.95249315662
sw_enthalpy(S,t,p)            -110776.712408975
sw_entropy(S,t,p)             -352.81879771528
sw_kappa(S,t,p)               -4.033862685464779e-6
sw_kappa_t(S,t,p)             -4.104037946151349e-6
sw_svel(S,t,p)                -1552.93372863425


###################################################
### chunk number 42: sw
###################################################
plotST <- function(fun,title)
{
  Sal <-  seq(0,40,by=0.5)
  Temp<- seq(-5,40,by=0.5)

  Val <- outer(X=Sal,Y=Temp,FUN=function(X,Y) fun(S=X, t=Y))
  contour(Sal,Temp,Val,xlab="Salinity",ylab="temperature",
          main=title,nlevel=20)
}

par (mfrow=c(3,2))
par(mar=c(4,4,3,2))
plotST(sw_gibbs,"Gibbs function")
plotST(sw_cp,"Heat capacity")
plotST(sw_entropy,"Entropy")
plotST(sw_enthalpy,"Enthalpy")
plotST(sw_dens,"Density")
plotST(sw_svel,"Sound velocity")


###################################################
### chunk number 43: sw
###################################################
plotST <- function(fun,title)
{
  Sal <-  seq(0,40,by=0.5)
  Temp<- seq(-5,40,by=0.5)

  Val <- outer(X=Sal,Y=Temp,FUN=function(X,Y) fun(S=X, t=Y))
  contour(Sal,Temp,Val,xlab="Salinity",ylab="temperature",
          main=title,nlevel=20)
}

par (mfrow=c(3,2))
par(mar=c(4,4,3,2))
plotST(sw_gibbs,"Gibbs function")
plotST(sw_cp,"Heat capacity")
plotST(sw_entropy,"Entropy")
plotST(sw_enthalpy,"Enthalpy")
plotST(sw_dens,"Density")
plotST(sw_svel,"Sound velocity")


###################################################
### chunk number 44: sw2
###################################################
par (mfrow=c(3,2))
par(mar=c(4,4,3,2))
plotST(sw_kappa,"Isentropic compressibility")
plotST(sw_kappa_t,"Isothermal compressibility")
plotST(sw_alpha,"Thermal expansion coefficient")
plotST(sw_beta,"Haline contraction coefficient")
plotST(sw_adtgrad,"Adiabatic temperature gradient")
par (mfrow=c(1,1))


###################################################
### chunk number 45: sw2
###################################################
par (mfrow=c(3,2))
par(mar=c(4,4,3,2))
plotST(sw_kappa,"Isentropic compressibility")
plotST(sw_kappa_t,"Isothermal compressibility")
plotST(sw_alpha,"Thermal expansion coefficient")
plotST(sw_beta,"Haline contraction coefficient")
plotST(sw_adtgrad,"Adiabatic temperature gradient")
par (mfrow=c(1,1))


###################################################
### chunk number 46: sw3
###################################################
par (mfrow=c(2,2))
par(mar=c(4,4,3,2))
plotST(function(S,t) sw_dens(S,t,method="UNESCO")-sw_dens(S,t),
  "Density UNESCO - Gibbs")
plotST(function(S,t) sw_cp(S,t,method="UNESCO")-sw_cp(S,t),
  "Heat capacity UNESCO - Gibbs")
plotST(function(S,t) sw_svel(S,t,method="UNESCO")-sw_svel(S,t),
  "Sound velocity UNESCO - Gibbs")
par (mfrow=c(1,1))


###################################################
### chunk number 47: sw3
###################################################
par (mfrow=c(2,2))
par(mar=c(4,4,3,2))
plotST(function(S,t) sw_dens(S,t,method="UNESCO")-sw_dens(S,t),
  "Density UNESCO - Gibbs")
plotST(function(S,t) sw_cp(S,t,method="UNESCO")-sw_cp(S,t),
  "Heat capacity UNESCO - Gibbs")
plotST(function(S,t) sw_svel(S,t,method="UNESCO")-sw_svel(S,t),
  "Sound velocity UNESCO - Gibbs")
par (mfrow=c(1,1))


###################################################
### chunk number 48: 
###################################################
1/molweight("CO3")
1/molweight("HCO3")
1/molweight(c("C2H5OH", "CO2", "H2O"))

molweight(c("SiOH4", "NaHCO3", "C6H12O6", "Ca(HCO3)2", "Pb(NO3)2", "(NH4)2SO4"))


###################################################
### chunk number 49: 
###################################################
gs <- gas_solubility()
species <- colnames(gs)
mw <- molweight(species)


###################################################
### chunk number 50: mwgs
###################################################
plot(mw,gs,type="n",xlab="molecular weight", ylab="solubility", log="y")
text(mw,gs,species)


###################################################
### chunk number 51: mwgs
###################################################
plot(mw,gs,type="n",xlab="molecular weight", ylab="solubility", log="y")
text(mw,gs,species)


###################################################
### chunk number 52: 
###################################################
molvol(species="ideal")
molvol(species="ideal",t=1:10)


###################################################
### chunk number 53: 
###################################################
1/molvol(species="O2",t=0)*1000
1/molvol(species="O2",q=1:6,t=0)
1/molvol(t=1:5,species=c("CO2","O2","N2O"))


###################################################
### chunk number 54: 
###################################################
redfield(1, "P")


###################################################
### chunk number 55: 
###################################################
redfield(1, "N")


###################################################
### chunk number 56: 
###################################################
redfield(2, "P", "mass")


###################################################
### chunk number 57: 
###################################################
x <- redfield(1, "P", "mass")
x / sum(x)


###################################################
### chunk number 58: 
###################################################
stumm <- c(C=106, H=180, O=45, N=16, P=1)
x <- redfield(1, "P", "mass", ratio = stumm)
x / sum(x)


###################################################
### chunk number 59: 
###################################################
convert_p(1, "atm")


###################################################
### chunk number 60: 
###################################################
convert_T(1, "C")


###################################################
### chunk number 61: 
###################################################
convert_StoCl(S=35)
convert_RtoS(R=1)
convert_StoR(S=35)


